@@ -2,9 +2,9 @@ import dataclasses
 
 import jax
 from jax import numpy as jnp
-from overrides import final, overrides
+from overrides import overrides
 
-from . import _base, types
+from . import _base, annotations
 from ._so2 import SO2
 from .utils import get_epsilon, register_lie_group
 
@@ -21,10 +21,9 @@ class SE2(_base.SEBase):
 
     # SE2-specific
 
-    unit_complex_xy: types.Vector
+    unit_complex_xy: annotations.Vector
     """Internal parameters. `(cos, sin, x, y)`."""
 
-    @final
     @overrides
     def __repr__(self) -> str:
         unit_complex = jnp.round(self.unit_complex_xy[..., :2], 5)
@@ -32,7 +31,9 @@ class SE2(_base.SEBase):
         return f"{self.__class__.__name__}(unit_complex={unit_complex}, xy={xy})"
 
     @staticmethod
-    def from_xy_theta(x: types.Scalar, y: types.Scalar, theta: types.Scalar) -> "SE2":
+    def from_xy_theta(
+        x: annotations.Scalar, y: annotations.Scalar, theta: annotations.Scalar
+    ) -> "SE2":
         cos = jnp.cos(theta)
         sin = jnp.sin(theta)
         return SE2(unit_complex_xy=jnp.array([cos, sin, x, y]))
@@ -40,39 +41,34 @@ class SE2(_base.SEBase):
     # SE-specific
 
     @staticmethod
-    @final
     @overrides
     def from_rotation_and_translation(
         rotation: SO2,
-        translation: types.Vector,
+        translation: annotations.Vector,
     ) -> "SE2":
         assert translation.shape == (2,)
         return SE2(
             unit_complex_xy=jnp.concatenate([rotation.unit_complex, translation])
         )
 
-    @final
     @overrides
     def rotation(self) -> SO2:
         return SO2(unit_complex=self.unit_complex_xy[..., :2])
 
-    @final
     @overrides
-    def translation(self) -> types.Vector:
+    def translation(self) -> annotations.Vector:
         return self.unit_complex_xy[..., 2:]
 
     # Factory
 
     @staticmethod
-    @final
     @overrides
     def identity() -> "SE2":
         return SE2(unit_complex_xy=jnp.array([1.0, 0.0, 0.0, 0.0]))
 
     @staticmethod
-    @final
     @overrides
-    def from_matrix(matrix: types.Matrix) -> "SE2":
+    def from_matrix(matrix: annotations.Matrix) -> "SE2":
         assert matrix.shape == (3, 3)
         # Currently assumes bottom row is [0, 0, 1]
         return SE2.from_rotation_and_translation(
@@ -82,14 +78,12 @@ class SE2(_base.SEBase):
 
     # Accessors
 
-    @final
     @overrides
-    def parameters(self) -> types.Vector:
+    def parameters(self) -> annotations.Vector:
         return self.unit_complex_xy
 
-    @final
     @overrides
-    def as_matrix(self) -> types.Matrix:
+    def as_matrix(self) -> annotations.Matrix:
         cos, sin, x, y = self.unit_complex_xy
         return jnp.array(
             [
@@ -102,9 +96,8 @@ class SE2(_base.SEBase):
     # Operations
 
     @staticmethod
-    @final
     @overrides
-    def exp(tangent: types.TangentVector) -> "SE2":
+    def exp(tangent: annotations.TangentVector) -> "SE2":
         # Reference:
         # > https://github.com/strasdat/Sophus/blob/a0fe89a323e20c42d3cecb590937eb7a06b8343a/sophus/se2.hpp#L558
         # Also see:
@@ -137,9 +130,8 @@ class SE2(_base.SEBase):
             translation=V @ tangent[:2],
         )
 
-    @final
     @overrides
-    def log(self: "SE2") -> types.TangentVector:
+    def log(self: "SE2") -> annotations.TangentVector:
         # Reference:
         # > https://github.com/strasdat/Sophus/blob/a0fe89a323e20c42d3cecb590937eb7a06b8343a/sophus/se2.hpp#L160
         # Also see:
@@ -169,9 +161,8 @@ class SE2(_base.SEBase):
         tangent = jnp.concatenate([V_inv @ self.translation(), theta[None]])
         return tangent
 
-    @final
     @overrides
-    def adjoint(self: "SE2") -> types.Matrix:
+    def adjoint(self: "SE2") -> annotations.Matrix:
         cos, sin, x, y = self.unit_complex_xy
         return jnp.array(
             [
@@ -182,7 +173,6 @@ class SE2(_base.SEBase):
         )
 
     @staticmethod
-    @final
     @overrides
     def sample_uniform(key: jnp.ndarray) -> "SE2":
         key0, key1 = jax.random.split(key)
