@@ -2,14 +2,14 @@ import dataclasses
 
 import jax
 from jax import numpy as jnp
-from overrides import final, overrides
+from overrides import overrides
 
-from . import _base, types
+from . import _base, annotations
 from ._so3 import SO3
 from .utils import get_epsilon, register_lie_group
 
 
-def _skew(omega: types.Vector) -> types.Matrix:
+def _skew(omega: annotations.Vector) -> annotations.Matrix:
     """Returns the skew-symmetric form of a length-3 vector. """
 
     wx, wy, wz = omega
@@ -34,10 +34,9 @@ class SE3(_base.SEBase):
 
     # SE3-specific
 
-    wxyz_xyz: types.Vector
+    wxyz_xyz: annotations.Vector
     """Internal parameters. wxyz quaternion followed by xyz translation."""
 
-    @final
     @overrides
     def __repr__(self) -> str:
         quat = jnp.round(self.wxyz_xyz[..., :4], 5)
@@ -47,37 +46,32 @@ class SE3(_base.SEBase):
     # SE-specific
 
     @staticmethod
-    @final
     @overrides
     def from_rotation_and_translation(
         rotation: SO3,
-        translation: types.Vector,
+        translation: annotations.Vector,
     ) -> "SE3":
         assert translation.shape == (3,)
         return SE3(wxyz_xyz=jnp.concatenate([rotation.wxyz, translation]))
 
-    @final
     @overrides
     def rotation(self) -> SO3:
         return SO3(wxyz=self.wxyz_xyz[..., :4])
 
-    @final
     @overrides
-    def translation(self) -> types.Vector:
+    def translation(self) -> annotations.Vector:
         return self.wxyz_xyz[..., 4:]
 
     # Factory
 
     @staticmethod
-    @final
     @overrides
     def identity() -> "SE3":
         return SE3(wxyz_xyz=jnp.array([1.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0]))
 
     @staticmethod
-    @final
     @overrides
-    def from_matrix(matrix: types.Matrix) -> "SE3":
+    def from_matrix(matrix: annotations.Matrix) -> "SE3":
         assert matrix.shape == (4, 4)
         # Currently assumes bottom row is [0, 0, 0, 1]
         return SE3.from_rotation_and_translation(
@@ -87,9 +81,8 @@ class SE3(_base.SEBase):
 
     # Accessors
 
-    @final
     @overrides
-    def as_matrix(self) -> types.Matrix:
+    def as_matrix(self) -> annotations.Matrix:
         return (
             jnp.eye(4)
             .at[:3, :3]
@@ -98,17 +91,15 @@ class SE3(_base.SEBase):
             .set(self.translation())
         )
 
-    @final
     @overrides
-    def parameters(self) -> types.Vector:
+    def parameters(self) -> annotations.Vector:
         return self.wxyz_xyz
 
     # Operations
 
     @staticmethod
-    @final
     @overrides
-    def exp(tangent: types.TangentVector) -> "SE3":
+    def exp(tangent: annotations.TangentVector) -> "SE3":
         # Reference:
         # > https://github.com/strasdat/Sophus/blob/a0fe89a323e20c42d3cecb590937eb7a06b8343a/sophus/se3.hpp#L761
 
@@ -138,9 +129,8 @@ class SE3(_base.SEBase):
             translation=V @ tangent[:3],
         )
 
-    @final
     @overrides
-    def log(self: "SE3") -> types.TangentVector:
+    def log(self: "SE3") -> annotations.TangentVector:
         # Reference:
         # > https://github.com/strasdat/Sophus/blob/a0fe89a323e20c42d3cecb590937eb7a06b8343a/sophus/se3.hpp#L223
         omega = self.rotation().log()
@@ -162,9 +152,8 @@ class SE3(_base.SEBase):
         )
         return jnp.concatenate([V_inv @ self.translation(), omega])
 
-    @final
     @overrides
-    def adjoint(self: "SE3") -> types.Matrix:
+    def adjoint(self: "SE3") -> annotations.Matrix:
         R = self.rotation().as_matrix()
         return jnp.block(
             [
@@ -174,7 +163,6 @@ class SE3(_base.SEBase):
         )
 
     @staticmethod
-    @final
     @overrides
     def sample_uniform(key: jnp.ndarray) -> "SE3":
         key0, key1 = jax.random.split(key)
