@@ -2,9 +2,9 @@ import dataclasses
 
 import jax
 from jax import numpy as jnp
-from overrides import final, overrides
+from overrides import overrides
 
-from . import _base, types
+from . import _base, annotations
 from .utils import get_epsilon, register_lie_group
 
 
@@ -20,17 +20,16 @@ class SO3(_base.SOBase):
 
     # SO3-specific
 
-    wxyz: types.Vector
+    wxyz: annotations.Vector
     """Internal parameters. `(w, x, y, z)` quaternion."""
 
-    @final
     @overrides
     def __repr__(self) -> str:
         wxyz = jnp.round(self.wxyz, 5)
         return f"{self.__class__.__name__}(wxyz={wxyz})"
 
     @staticmethod
-    def from_x_radians(theta: types.Scalar) -> "SO3":
+    def from_x_radians(theta: annotations.Scalar) -> "SO3":
         """Generates a x-axis rotation.
 
         Args:
@@ -42,7 +41,7 @@ class SO3(_base.SOBase):
         return SO3.exp(jnp.array([theta, 0.0, 0.0]))
 
     @staticmethod
-    def from_y_radians(theta: types.Scalar) -> "SO3":
+    def from_y_radians(theta: annotations.Scalar) -> "SO3":
         """Generates a y-axis rotation.
 
         Args:
@@ -54,7 +53,7 @@ class SO3(_base.SOBase):
         return SO3.exp(jnp.array([0.0, theta, 0.0]))
 
     @staticmethod
-    def from_z_radians(theta: types.Scalar) -> "SO3":
+    def from_z_radians(theta: annotations.Scalar) -> "SO3":
         """Generates a z-axis rotation.
 
         Args:
@@ -67,9 +66,9 @@ class SO3(_base.SOBase):
 
     @staticmethod
     def from_rpy_radians(
-        roll: types.Scalar,
-        pitch: types.Scalar,
-        yaw: types.Scalar,
+        roll: annotations.Scalar,
+        pitch: annotations.Scalar,
+        yaw: annotations.Scalar,
     ) -> "SO3":
         """Generates a transform from a set of Euler angles.
         Uses the ZYX mobile robot convention.
@@ -89,7 +88,7 @@ class SO3(_base.SOBase):
         )
 
     @staticmethod
-    def from_quaternion_xyzw(xyzw: types.Array) -> "SO3":
+    def from_quaternion_xyzw(xyzw: annotations.Array) -> "SO3":
         """Construct a rotation from an `xyzw` quaternion.
 
         Note that `wxyz` quaternions can be constructed using the default dataclass
@@ -108,14 +107,14 @@ class SO3(_base.SOBase):
         """Grab parameters as xyzw quaternion."""
         return jnp.roll(self.wxyz, shift=-1)
 
-    def as_rpy_radians(self) -> types.RollPitchYaw:
+    def as_rpy_radians(self) -> annotations.RollPitchYaw:
         """Computes roll, pitch, and yaw angles.
         Uses the ZYX mobile robot convention.
 
         Returns:
-            jaxlie.types.RollPitchYaw: Named tuple containing Euler angles in radians.
+            annotations.RollPitchYaw: Named tuple containing Euler angles in radians.
         """
-        return types.RollPitchYaw(
+        return annotations.RollPitchYaw(
             roll=self.compute_roll_radians(),
             pitch=self.compute_pitch_radians(),
             yaw=self.compute_yaw_radians(),
@@ -157,19 +156,17 @@ class SO3(_base.SOBase):
     # Factory
 
     @staticmethod
-    @final
     @overrides
     def identity() -> "SO3":
         return SO3(wxyz=jnp.array([1.0, 0.0, 0.0, 0.0]))
 
     @staticmethod
-    @final
     @overrides
-    def from_matrix(matrix: types.Matrix) -> "SO3":
+    def from_matrix(matrix: annotations.Matrix) -> "SO3":
         assert matrix.shape == (3, 3)
 
         # Modified from:
-        # > "Converting a Rotation types.Matrix to a Quaternion" from Mike Day
+        # > "Converting a Rotation Matrix to a Quaternion" from Mike Day
         # > https://d3cw3dd2w32x2b.cloudfront.net/wp-content/uploads/2015/01/matrix-to-quat.pdf
 
         def case0(m):
@@ -236,9 +233,8 @@ class SO3(_base.SOBase):
 
     # Accessors
 
-    @final
     @overrides
-    def as_matrix(self) -> types.Matrix:
+    def as_matrix(self) -> annotations.Matrix:
         norm = self.wxyz @ self.wxyz
         q = self.wxyz * jnp.sqrt(2.0 / norm)
         q = jnp.outer(q, q)
@@ -250,23 +246,20 @@ class SO3(_base.SOBase):
             ]
         )
 
-    @final
     @overrides
-    def parameters(self) -> types.Vector:
+    def parameters(self) -> annotations.Vector:
         return self.wxyz
 
     # Operations
 
-    @final
     @overrides
-    def apply(self: "SO3", target: types.Vector) -> types.Vector:
+    def apply(self: "SO3", target: annotations.Vector) -> annotations.Vector:
         assert target.shape == (3,)
 
         # Compute using quaternion multiplys
         padded_target = jnp.zeros(4).at[1:].set(target)
         return (self @ SO3(wxyz=padded_target) @ self.inverse()).wxyz[1:]
 
-    @final
     @overrides
     def multiply(self: "SO3", other: "SO3") -> "SO3":
         w0, x0, y0, z0 = self.wxyz
@@ -283,9 +276,8 @@ class SO3(_base.SOBase):
         )
 
     @staticmethod
-    @final
     @overrides
-    def exp(tangent: types.TangentVector) -> "SO3":
+    def exp(tangent: annotations.TangentVector) -> "SO3":
         # Reference:
         # > https://github.com/strasdat/Sophus/blob/a0fe89a323e20c42d3cecb590937eb7a06b8343a/sophus/so3.hpp#L583
 
@@ -317,9 +309,8 @@ class SO3(_base.SOBase):
             )
         )
 
-    @final
     @overrides
-    def log(self: "SO3") -> types.TangentVector:
+    def log(self: "SO3") -> annotations.TangentVector:
         # Reference:
         # > https://github.com/strasdat/Sophus/blob/a0fe89a323e20c42d3cecb590937eb7a06b8343a/sophus/so3.hpp#L247
 
@@ -339,24 +330,20 @@ class SO3(_base.SOBase):
 
         return atan_factor * self.wxyz[1:]
 
-    @final
     @overrides
-    def adjoint(self: "SO3") -> types.Matrix:
+    def adjoint(self: "SO3") -> annotations.Matrix:
         return self.as_matrix()
 
-    @final
     @overrides
     def inverse(self: "SO3") -> "SO3":
         # Negate complex terms
         return SO3(wxyz=self.wxyz * jnp.array([1, -1, -1, -1]))
 
-    @final
     @overrides
     def normalize(self: "SO3") -> "SO3":
         return SO3(wxyz=self.wxyz / jnp.linalg.norm(self.wxyz))
 
     @staticmethod
-    @final
     @overrides
     def sample_uniform(key: jnp.ndarray) -> "SO3":
         # Uniformly sample over S^4
